@@ -23,11 +23,11 @@ class MoneyWidget(MultiWidget):
         if not amount_widget:
             amount_widget = TextInput
         if not currency_widget:
-            currency_widget = Select(choices)
+            currency_widget = Select(choices=choices)
         widgets = (amount_widget, currency_widget)
         super(MoneyWidget, self).__init__(widgets, *args, **kwargs)
 
     def decompress(self, value):
         if value:
             return [value.amount, value.currency]
-        return [None, None]
\ No newline at end of file
+        return [None, None]
