@@ -198,10 +198,15 @@ class MoneyField(models.DecimalField):
 
     def __init__(self, verbose_name=None, name=None,
                  max_digits=None, decimal_places=None,
-                 default=0.0,
+                 default=None,
                  default_currency=DEFAULT_CURRENCY,
                  currency_choices=CURRENCY_CHOICES, **kwargs):
 
+        nullable = kwargs.get('null', False)
+        if default is None and not nullable:
+            # Backwards compatible fix for non-nullable fields
+            default = 0.0
+
         if isinstance(default, basestring):
             try:
                 # handle scenario where default is formatted like:
@@ -217,7 +222,7 @@ class MoneyField(models.DecimalField):
         elif isinstance(default, (float, Decimal, int)):
             default = Money(default, default_currency)
 
-        if not isinstance(default, Money):
+        if not (nullable and default is None) and not isinstance(default, Money):
             raise Exception(
                 "default value must be an instance of Money, is: %s" % str(
                     default))
@@ -336,6 +341,18 @@ class MoneyField(models.DecimalField):
         kwargs['default_currency'] = "'%s'" % self.default_currency
         return field_class, args, kwargs
 
+    ## Django 1.7 migration support
+    def deconstruct(self):
+        name, path, args, kwargs = super(MoneyField, self).deconstruct()
+
+        if self.default:
+            kwargs['default'] = self.default.amount
+        if self.default_currency != DEFAULT_CURRENCY:
+            kwargs['default_currency'] = self.default_currency
+        if self.currency_choices != CURRENCY_CHOICES:
+            kwargs['currency_choices'] = self.currency_choices
+        return name, path, args, kwargs
+
 
 try:
     from south.modelsinspector import add_introspection_rules
